pub struct ClosedOrbit {
base_orbit: OrbitBase,
period: (I32F32, I32F32, I32F32),
max_image_dt: I32F32,
done: BitBox<usize, Lsb0>,
segments: Vec<OrbitSegment>,
}Expand description
Represents a closed orbit with a fixed period, image time information, and completion status.
Fields
base_orbit: OrbitBaseThe base configuration and parameters of the orbit.
period: (I32F32, I32F32, I32F32)The period of the orbit defined as a tuple:
- First element represents the total orbit time.
- Second and third element represent the x/y-period respectively.
max_image_dt: I32F32Maximum time interval between images that ensures proper coverage of the orbit.
done: BitBox<usize, Lsb0>A bitvector indicating the completion status of orbit segments.
segments: Vec<OrbitSegment>A vector containing all of the orbits segments.
Implementations
Sourceimpl ClosedOrbit
impl ClosedOrbit
Sourceconst EXPORT_ORBIT_ENV: &'static str = "EXPORT_ORBIT"
const EXPORT_ORBIT_ENV: &'static str = "EXPORT_ORBIT"
ENV Var marking that the orbit configuration should be exported
Sourceconst TRY_IMPORT_ENV: &'static str = "TRY_IMPORT_ORBIT"
const TRY_IMPORT_ENV: &'static str = "TRY_IMPORT_ORBIT"
ENV Var marking that it should be tried to import the orbit configuration
Sourceconst DEF_FILEPATH: &'static str = "orbit.bin"
const DEF_FILEPATH: &'static str = "orbit.bin"
File were the orbit should be serialized to/deserialized from
Sourcepub fn new(
base_orbit: OrbitBase,
lens: CameraAngle,
) -> Result<Self, OrbitUsabilityError>
pub fn new( base_orbit: OrbitBase, lens: CameraAngle, ) -> Result<Self, OrbitUsabilityError>
Creates a new ClosedOrbit instance using a given OrbitBase and CameraAngle.
Arguments
try_orbit: The base orbit to initialize the closed orbit.lens: The camera lens angle used to determine image overlaps.
Returns
Ok(ClosedOrbit)if the orbit is closed and sufficient overlap exists.Err(OrbitUsabilityError)if the orbit doesn’t meet the requirements.
Sourcepub fn clear_done(&mut self)
pub fn clear_done(&mut self)
Clears all completion tracking for the orbit.
Sourcepub fn try_from_env() -> Option<Self>
pub fn try_from_env() -> Option<Self>
Tries to import a previously serialized orbit if environment variable TRY_IMPORT_ORBIT=1.
Sourcepub fn try_export_default(&self)
pub fn try_export_default(&self)
Tries to export the current orbit to disk if EXPORT_ORBIT=1 is set in the environment.
Sourcefn import_from(filename: &'static str) -> Result<Self, Error>
fn import_from(filename: &'static str) -> Result<Self, Error>
Deserializes a saved orbit from disk.
Sourcefn export_to(&self, filename: &'static str) -> Result<(), EncodeError>
fn export_to(&self, filename: &'static str) -> Result<(), EncodeError>
Serializes the orbit to a given file path using fixed-size encoding.
Sourcefn get_serde_config() -> Configuration<LittleEndian, Fixint>
fn get_serde_config() -> Configuration<LittleEndian, Fixint>
Returns a bincode serialization config with little-endian fixed-width layout.
Sourcefn compute_segments(
base_point: &Vec2D<I32F32>,
vel: &Vec2D<I32F32>,
) -> Vec<OrbitSegment>
fn compute_segments( base_point: &Vec2D<I32F32>, vel: &Vec2D<I32F32>, ) -> Vec<OrbitSegment>
Computes all forward-wrapped orbit segments.
Sourcepub fn get_p_t_reordered(
&self,
shift_start: usize,
shift_end: usize,
) -> Box<dyn Iterator<Item = BitRef<'_>> + '_>
pub fn get_p_t_reordered( &self, shift_start: usize, shift_end: usize, ) -> Box<dyn Iterator<Item = BitRef<'_>> + '_>
Returns an iterator that reorders the done bitvector sequence based on a specified shift.
Arguments
shift_start: The starting index of the reordering shift.shift_end: The ending index of the reordering shift.
Returns
- An iterator over the reordered
donebitvector segment.
Panics
- If
shift_startorshift_endexceed the length of the bitvector.
Sourcepub fn mark_done(&mut self, first_i: usize, last_i: usize)
pub fn mark_done(&mut self, first_i: usize, last_i: usize)
Marks a specified range of orbit segments as completed in the done bitvector.
Arguments
first_i: The first index of the range to mark as completed.last_i: The last index of the range to mark as completed.
pub fn get_closest_deviation(&self, pos: Vec2D<I32F32>) -> (VecAxis, I32F32)
Sourcepub fn max_image_dt(&self) -> I32F32
pub fn max_image_dt(&self) -> I32F32
Returns the maximum image time interval for the orbit.
Returns
I32F32representing the maximum imaging time interval.
Sourcepub fn base_orbit_ref(&self) -> &OrbitBase
pub fn base_orbit_ref(&self) -> &OrbitBase
Returns a reference to the base orbit configuration.
Returns
- A reference to the associated
OrbitBase.
Sourcepub fn period(&self) -> (I32F32, I32F32, I32F32)
pub fn period(&self) -> (I32F32, I32F32, I32F32)
Returns the period tuple of the closed orbit.
Returns
- A tuple
(I32F32, I32F32, I32F32)representing the orbit’s period.
Sourcepub fn will_visit(&self, pos: Vec2D<I32F32>) -> bool
pub fn will_visit(&self, pos: Vec2D<I32F32>) -> bool
Sourcepub fn get_i(&self, pos: Vec2D<I32F32>) -> Option<usize>
pub fn get_i(&self, pos: Vec2D<I32F32>) -> Option<usize>
Returns the done-vector index corresponding to the current position, if on the orbit.
Sourcepub(super) fn segments(&self) -> &Vec<OrbitSegment>
pub(super) fn segments(&self) -> &Vec<OrbitSegment>
Returns a reference to all orbit segments.
Sourcepub fn get_coverage(&self) -> I32F32
pub fn get_coverage(&self) -> I32F32
Calculates the coverage from the done - bitmap